==> rhapsodie_0.5.0.tar.gz: rhapsodie-0.5.0/src/app.h <==
/*************************************************************************}
{ app.h - application wrapper                                             }
{                                                                         }
{ This file is a part of the project                                      }
{   Rhapsodie - Music player for N900                                     }
{                                                                         }
{ (c) Alexey Parfenov, 2012                                               }
{                                                                         }
{ e-mail: zxed@alkatrazstudio.net                                         }
{                                                                         }
{ This program is free software; you can redistribute it and/or           }
{ modify it under the terms of the GNU General Public License             }
{ as published by the Free Software Foundation; either version 3 of       }
{ the License, or (at your option) any later version.                     }
{                                                                         }
{ This program is distributed in the hope that it will be useful,         }
{ but WITHOUT ANY WARRANTY; without even the implied warranty of          }
{ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU        }
{ General Public License for more details.                                }
{                                                                         }
{ You may read GNU General Public License at:                             }
{   http://www.gnu.org/copyleft/gpl.html                                  }
{                                                                         }
{ last modified: 21 Mar 2012                                              }
{*************************************************************************/

#ifndef APP_H
#define APP_H

#include "includes.h"
#include "mainwindow.h"

class App : public QApplication
{
    Q_OBJECT

public:
    explicit App(int &argc, char **argv);
    ~App();

protected:
    void loadTranslators();
    void createUi();
    void init();

    MainWindow* mainWindow;
    QTranslator* qtTranslator;
    QTranslator* myappTranslator;
};

#endif // APP_H

==> rhapsodie_1.0.0.tar.gz: rhapsodie-1.0.0/src/app.h <==
/*************************************************************************}
{ app.h - application wrapper                                             }
{                                                                         }
{ This file is a part of the project                                      }
{   Rhapsodie - Music player for N900                                     }
{                                                                         }
{ (c) Alexey Parfenov, 2012                                               }
{                                                                         }
{ e-mail: zxed@alkatrazstudio.net                                         }
{                                                                         }
{ This program is free software; you can redistribute it and/or           }
{ modify it under the terms of the GNU General Public License             }
{ as published by the Free Software Foundation; either version 3 of       }
{ the License, or (at your option) any later version.                     }
{                                                                         }
{ This program is distributed in the hope that it will be useful,         }
{ but WITHOUT ANY WARRANTY; without even the implied warranty of          }
{ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU        }
{ General Public License for more details.                                }
{                                                                         }
{ You may read GNU General Public License at:                             }
{   http://www.gnu.org/copyleft/gpl.html                                  }
{                                                                         }
{ last modified: 27 Nov 2012                                              }
{*************************************************************************/

#ifndef APP_H
#define APP_H

#include "includes.h"
#include "mainwindow.h"
#include "../inc/coreapp.h"

class App : public CoreApp
{
    Q_OBJECT

public:
    explicit App(int &argc, char **argv);
    ~App();

protected:
    void loadTranslators();
    void createUi();
    void init();
    virtual int main();

    MainWindow* mainWindow;
    QTranslator* qtTranslator;
    QTranslator* myappTranslator;
};

#endif // APP_H
